Function to build parameter bounds based on Holsman et al 2015 and Kinzey and Punt 2010
Arguments
- param_list
Parameter list object built from
build_params- data_list
a Rceattle data object
Function to build parameter bounds based on Holsman et al 2015 and Kinzey and Punt 2010
Parameter list object built from build_params
a Rceattle data object