Convert intuitive text strings to integer switches for TMB
Source:R/5-rearrange_data.R
convert_switches.RdConvert intuitive text strings to integer switches for TMB
R/5-rearrange_data.R
convert_switches.RdConvert intuitive text strings to integer switches for TMB