Function to update hindcast and set F to 0. Useful for determining dynamic reference points for multi-species models under climate-change.
Function to update hindcast and set F to 0. Useful for determining dynamic reference points for multi-species models under climate-change.