Data inputs for single species CEATTLE of the Bering Sea from 1979 to 2017
Source:R/data.R
BS2017SS.RdA dataset containing the inputs used for CEATTLE
Format
Control
- nspp
Number of species included in CEATTLE
- styr
Start year of the hindcast
- endyr
End year of the hindcast
- projyr
End year of the forecast
- nsex
Number of sexes to model in the population (1 = combined/1sex, 2 = models both female/male)
- spawn_month
Spawning month of the population to adjust the numbers spawning
- R_sexr
Percent of recruitment that is female (ignored if nsex = 1)
- nages
Number of ages of each species included in the hindcast
- minage
Minimum age for each population (i.e.does recruitment correspond to age 0, 1, 2?)
- nlengths
Number of lengths of each species included in the hindcast
- pop_wt_index
Weight-at-age (weight) index to use for calculation of each species population derived quantities (SSB, Consumption/Ration, Suitability, etc)
- ssb_wt_index
Weight-at-age (weight) index to use for calculation of each species spawning biomass
- pop_age_transition_index
Age transition matrix (e.g. growth trajectory) index to use for derived quantities of the population to convert age to length (also used in length-based predation estimation)
- sigma_rec_prior
Standard deviation to use for recruitment
- other_food
Other food in the ecosystem for each species
- estDynamics
Estimate or fix numbers-at-age: 0 = estimate dynamics, 1 = use input numbers-at-age in NbyageFixed, 2 = multiply input numbers-at-age (NbyageFixed) by a single scaling coefficient, 3 = multiply input numbers-at-age (NbyageFixed) by age specific scaling coefficient.
- est_M1
Estimate residual (multi-species mode) or total natural mortality (single-species mode). 0 = use fixed natural mortality from M1_base, 1 = estimate sex- and age-invariant M1, 2 = sex-specific (two-sex model), age-invariant M1, 3 = estimate sex- and age-specific M1.
- fleet_control
Survey and fishery data specifications
- index_data
Survey index in weight (kg) or numbers data
- catch_data
Total catch in weight (kg) or numbers data
- comp_data
Survey/fishery age or length composition data. Note if sex is 3, put female composition data then male composition data (similar to SS).
- emp_sel
Empirical/fixed selectivity for surveys and fisheries (leave empty if not used)
- age_trans_matrix
Age transition matrix (e.g. growth trajectory) used to convert age to length for length comp data. Can have multiple matrices for a species specified by Age_transition_index.
- age_error
Aging error matrices. Can have only one per species.
- weight
Weight-at-age (weight) to use for calculation of derived quantities (SSB, Consumption/Ration, Suitability, Total Catch, Survey Biomass, etc). Can have multiple weight-at-age data-sets for each species, but must be full for all years of the hindcast.
- maturity
Maturity-at-age for each species
- sex_ratio
Percent female at age for each species
- M1_base
Residual natural mortality for each species
- aLW
Parameters for weight-at-length power function for each species. . Used when estimating time-variant length-based gamma suitability (suitMode = 2) or time-variant length-based lognormal suitability (suitMode = 5)
- Ceq
Which bioenergetics equation to use for each species for ft to scale max consumtion: 1 = Exponential (Stewart et al 1983), 2 = Temperature-dependendence for warm-water species (Kitchell et al 1977; sensu Holsman et al 2015), 3 = temperature dependence for cool and cold-water species (Thornton and Lessem 1979)
- Cindex
Which environmental index in env_data to use to drive bioenergetics
- Pvalue
This scales the maximum consumption used for ration for each species; Pvalue is in CmaxfTPvalue*ration_data
- fday
Number of foraging days per year for each species
- CA
Intercept of allometric mass function for calculating maximum consumption: CA * Weight ^ CB
- CB
Slope of allometric mass function for calculating maximum consumption: CA * Weight ^ CB
- Qc
Parameter for temperature scaling function of maximum consumption specified by Ceq
- Tco
Parameter for temperature scaling function of maximum consumption specified by Ceq
- Tcm
Parameter for temperature scaling function of maximum consumption specified by Ceq
- Tcl
Parameter for temperature scaling function of maximum consumption specified by Ceq
- CK1
Parameter for temperature scaling function of maximum consumption specified by Ceq
- CK4
Parameter for temperature scaling function of maximum consumption specified by Ceq
- env_data
Environmental indices such as bottom temperature data to incorporate into ration equation specificed by Ceq and Cindex. Also used to drive catchability if Catchability = 5. Will use the mean for missing years. Temperature should be in celcius.
- ration_data
Annual relative foraging rate by age or input consumption at age. Multiplied by pvalue and fday to scale maximum consumption to the number of days in a year that foraging occurs.
- UobsAge
Stomach proportion by numbers for each predator, prey, predator age, prey age combination. Can also be year specific by including the column, "Year"
- UobsWtAge
Stomach proportion by weight for each predator, prey, predator age, prey age combination. Can also be year specific by including the column, "Year"
fleet_control: controls for survey and fisheries data
- Fleet_name
Name of survey or fishery
- Fleet_code
Index of survey/fishery ACROSS species
- Fleet_type
0 or 'Off' = Do not estimate; 1 = 'Fishery'; 2 = 'Survey'
- Species
Species number
- Selectivity_index
index to use if selectivities of different surveys are to be the same
- Selectivity
Selectivity to use for the species: 0 = "Fixed"; 1 = "Logistic"; 2 = "NonParametric" sensu Ianelli et al 2018; 3 = "DoubleLogistic"; 4 = "DescendingLogistic", 5 = "Hake" non-parametric sense Taylor et al, 6 = "2DAR1", 7 = "3DAR1" sensu Cheng et al 2024.
- Selectivity_dimension
"Age" or "Length".
- Nselages
Number of ages to estimate non-parametric selectivity.
- Time_varying_sel
Whether a time-varying selectivity should be estimated for logistic, double logistic selectivity, or descending logistic. 0 = "Off", 1 = "IID" penalized deviates given sel_sd_prior or random effect, 2 = "AR1" (TODO), 3 = "Block" time blocks with no penalty, 4 = "RandomWalk" following Dorn, 5 = "RandomWalkAscending" on ascending portion of double logistic only.
- Time_varying_sel_sd_prior
The fixed or initial sd to use for time varying selectivity.
- Bin_first_selected
Age/length bin at which selectivity is non-zero
- Acuumulation_age_lower
Ages below this will be grouped to this age for composition data. For example, if set to 2, comp data for age 2 will include 1 and 2 year olds.
- Acuumulation_age_upper
Ages above this will be grouped to this age for composition data. For example, if set to 9 for a species with 10 ages, comp data for age 9 will include 9 and 10 year olds.
- weight1_Numbers2
Is the observation in weight (kg) set as 1, if the observation is in numbers caught, set as 2
- Weight_index
Weight-at-age (weight) index to use for calculation of derived quantities
- Age_transition_index
Age transition matrix (e.g. growth trajectory) index to use for derived quantities to convert age to length
- Q_index
index to use if catchability coefficients are to be set the same
- Catchability
Estimate catchability? (0 or "Fixed" = fixed at prior; 1 or "Estimated" = Estimate single parameter; 2 or "Estimated-with-prior" = Estimate single parameter with prior; 3 or "Analytical" = Estimate analytical q from Ludwig and Walters 1994; - 4 = Estimate power equation; - 5 or "Environmental" = Linear equation log(q_y) = q_mu + beta * index_y; 6 or "AR1" = annual AR1 catchability deviates are fit to environmental index sensu Rogers et al 2025)
- Q_prior
Starting value or fixed value for catchability
- Q_sd_prior
Variance of q prior: dnorm (log_q, log_q_prior, q_sd_prior)
- Time_varying_q
Whether a time-varying q should be estimated. 0 = "Off", 1 = "IID" penalized deviate or random effect, 2 = "AR1" (TODO), 3 = "Block" time blocks with no penalty; 4 = "RandomWalk" random walk from mean following Dorn 2018 (dnorm(q_y - q_y-1, 0, sigma). If Catchability = 5 or 6, this determines the environmental index to be used in the equation log(q_y) = q_mu + beta * index_y
- Time_varying_q_sd_prior
The sd to use for the random walk of time varying q if set to 1
- Estimate_survey_sd
Estimate survey variance (0 = use CV from index_data, 1 = yes, 2 = analytically estimate following (Ludwig and Walters 1994)
- Survey_sd_prior
Starting value to be used if Estimate_sigma_index = 1
- Estimate_catch_sd
Estimate fishery variance (0 = use CV from index_data, 1 = yes, 2 = analytically estimate following (Ludwig and Walters 1994)
- Catch_sd_prior
Starting value to be used if Estimate_sigma_catch = 1
- Comp_weights
Composition weights to be used for multinomial likelihood. These are multiplied. After running model, these will update to McAllister & Ianelli 1997 weights using the harmonic mean.
- Catch_units
Units used for survey: 1 = kg; 2 = numbers
- proj_F_prop
The proportion of future fishing mortality assigned to this fleet
- Sex
sex codes: 0=combined; 1=use female only; 2=use male only; 3 = joint female and male