R/data.R
GeorgesBank3spp.Rd
A data list containing inputs for a multispecies CEATTLE model fit to three groundfish species on Georges Bank. See BS2017SS for format details.
BS2017SS
GeorgesBank3spp
A list with the same structure as BS2017SS.