R/2-build_map.R
build_map_debug.Rd
Sets all parameters in the map list to NA, except the dummy parameter, for use in debug or testing modes.
dummy
build_map_debug(map_list, debug)
The current TMB map list.
Logical. If TRUE, debug mode is activated.
Updated map_list.
map_list