This function checks the CAAL data for zero sum rows, handles NA values, and verifies that the CAAL data spans the required range of ages
Arguments
- data_list
A list containing the following components:
caal_obs: A matrix or data frame of composition observations.
caal_data: A data frame with metadata including species, sex, and age/length information.
nsex: A vector of sex counts by species.
nages: A vector of age counts by species.
nlengths: A vector of length counts by species. throws An error if any rows of
caal_obssum to 0 or if the composition data does not span the range of ages